/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */
#include "CyclopsSetting.h"

#include "controllers/common/family/Families.h"
#include <boost/lexical_cast.hpp>

using namespace boost;
using namespace std;

namespace cyclops {

const std::string CyclopsSetting::TYPE = "Cyclopssetting";



CyclopsSetting::CyclopsSetting(const string& name) :
			ExperimentController(name), controller::Start(this) {

	setFamily(family::ACQUISITION, family::SETTING);

	mode.init(this, SAVE, "actualmode", "wantedmode");
	nbKine.init(this, SAVE, "nbKine");
	kineTime.init(this, SAVE, "kineTime");
	gain.init(this, SAVE, "gain");
	modeBP.init(this, SAVE, "modeBP");
	fileDirectory.init(this, SAVE, "fileDirectory");
	fileName.init(this, SAVE, "fileName");
	m_CamDriver.init(this, "cammeraDriver");

	registerFunction(TYPE);




}

CyclopsSetting::~CyclopsSetting() {
}

void CyclopsSetting::postConfiguration() {

	//	mode=m_CamDriver->acqmode();
	//stringmode=MODE[mode()];

	registerRefresher(mode, &CyclopsSetting::refreshMode, this);
	//	registerUpdater(m_CamDriver->acqmode, &CyclopsSetting::updateMode, this);

}

void CyclopsSetting::start() {
	// Test speed BOB
	//hbinning.setpoint = 1;
	//vbinning.setpoint = 2088;


	m_CamDriver->acqmode = mode.setpoint();
	m_CamDriver->nbSlicesAcq = nbKine();
	m_CamDriver->bpixel = modeBP();
	m_CamDriver->gain = gain();

	m_CamDriver->execute("writeParam");

}


void CyclopsSetting::refreshMode(int32 value) {
	if (mode.setpoint()==0){
		nbKine=1;
		m_CamDriver->nbSlicesAcq = 1;
	}
}

void CyclopsSetting::updateMode() {

	//	mode=m_CamDriver->acqmode();

}

}

