/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "RemoteDPPTest.h"
#include <common/base/ServerProperties.h>
#include <boost/thread.hpp>
#include <boost/bind.hpp>
#include <boost/lexical_cast.hpp>
#include <boost/property_tree/json_parser.hpp>
#include <cstdlib>

namespace npp {

using namespace std;
using namespace common;
using namespace boost;
using namespace cameo;
using namespace lstdpp128;

using boost::property_tree::ptree;

const std::string RemoteDPPTest::TYPE = "remote_dpp_test";

RemoteDPPTest::RemoteDPPTest(const std::string& name) :
	RemoteDPPLiveProcess(name) {

	maxBlock.init(this, SAVE, "max_block");
	refreshTimeS.init(this, SAVE, "refresh_time_s");
}

RemoteDPPTest::RemoteDPPTest(const RemoteDPPTest& controller) :
	RemoteDPPLiveProcess(controller) {
}

RemoteDPPTest::~RemoteDPPTest() {
}

void RemoteDPPTest::postConfiguration() {

	RemoteDPPLiveProcess::postConfiguration();

	resetData();
}

void RemoteDPPTest::setDetectorControllers(const std::vector<ControllerPtr<acquisition::DetectorController> > & detectorControllers) {

	DPPLiveProcess::setDetectorControllers(detectorControllers);

	// Register the list mode data
	int32 index = 0;
	for (vector<ControllerPtr<acquisition::DetectorController> >::const_iterator c = detectorControllers.begin(); c != detectorControllers.end(); ++c) {
		// Force the attachment to receive updates
		(*c)->attach(this);
		registerUpdater((*c)->listModeData, &RemoteDPPTest::updateListModeData, this, index);
		index++;
	}
}

void RemoteDPPTest::start() {

	cout << "RemoteDPPTest::start" << endl;

	// Need a mutex to avoid having two start at the same time.
	{
		boost::mutex::scoped_lock lock(m_mutex);

		resetData();

		// Numor
		string numor;
		size_t size = fileName().size();

		if (size < 6) {
			string prefix(6 - size, '0');
			numor = prefix + fileName();
		} else {
			numor = fileName();
		}

		string outputName = ServerProperties::getInstance()->getNomadDataPath() + "/" + numor + ".lst-test";

		if (m_file.is_open()) {
			m_file.close();
		}
		m_file.open(outputName.c_str(), ios::binary);

		cout << getName() << " open " << outputName << endl;
	}
}

void RemoteDPPTest::stop() {

	if (m_file.is_open()) {
		m_file.close();

		//cout << "File " << m_file << " is closed" << endl;
	}
}

void RemoteDPPTest::raz() {
	resetData();
}

void RemoteDPPTest::updateListModeData(int index) {

	if (m_file.is_open()) {
		int32 size = detectorControllers[index]->listModeData.getSize();
		int32 * memoryBlock = detectorControllers[index]->listModeData();

		// Put the array into a string
		string data(reinterpret_cast<char *>(memoryBlock), sizeof(int32) * size);

		// Send the data
		m_file << data;
	}
}

void RemoteDPPTest::resetData() {
}

}

