/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef REALPSLDRIVER_H
#define REALPSLDRIVER_H

#include "Utilities/Counter.h"
#include "PslDef.h"
#include "PslState.h"

namespace psl {
class PslDriver;

/*!
 * \class RealPslDriver
 * \brief Real implementation class for the Psl device driver
 *
 * This class is a real implementation of Psl device driver.
 */
class RealPslDriver: public PslState {

public:

	/*!
	 * \brief Constructor
	 * \param[in] owner The device driver main class link
	 */
	RealPslDriver(PslDriver* owner);

	/*!
	 * \brief Destructor
	 */
	virtual ~RealPslDriver();

	/*!
	 * \brief Init command implementation
	 */
	virtual void init();

	/*!
	 * \brief Clear command implementation
	 */
	virtual void clear();

	/*!
	 * \brief Write Param command implementation
	 */
	virtual void writeParam();

	/*!
	 * \brief Read command implementation
	 */
	virtual void read();

	/*!
	 * \brief Synchronize Read command implementation
	 */
	virtual void synchroniseRead();

	/*!
	 * \brief Start command implementation
	 */
	virtual void start();

	/*!
	 * \brief Resume command implementation
	 */
	virtual void resume();

	/*!
	 * \brief Pause command implementation
	 */
	virtual void pause();

	/*!
	 * \brief Stop command implementation
	 */
	virtual void stop();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readStatus();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readInfos();
	int32 GetAvailableCameras();

private:

	std::string writeAndRead(const std::string& command, const std::string& terminator);
	std::string writeAndRead(const std::string& command, const std::string& terminator,const uint32 nbchar);

	int16 m_Handle;
	int16 lNumCameras;
	Counter m_TimeCounter;
};

}
#endif //REALPSLDRIVER_H
