/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef STEREOFLUXGATEDRIVER_H
#define STEREOFLUXGATEDRIVER_H

#include <Driver.h>
#include "StereoFluxgateDef.h"


namespace stereo_fluxgate {

/*!
 * \class StereoFluxgateDriver
 * \brief Main class for the StereoFluxgateDriver for the stereo magnetometer
 *
 * \par
 * Class for StereoFluxgateDriver. Implements DeviceDriver methods.
 * \par
 * The StereoFluxgateDriver device manages the global functionality of the stereo magnetometry.
 */

class StereoFluxgateDriver: public virtual DeviceDriver{

	friend class RealStereoFluxgateDriver;
	friend class PerfectStereoFluxgateDriver;

public:

	//! Driver type value
	static const std::string TYPE;

	/*!
	 * \brief Constructor
	 * \param[in] name the name of the device driver
	 */
	StereoFluxgateDriver(const std::string& name);

	/*!
	 * \brief Destructor
	 */
	virtual ~StereoFluxgateDriver();

	/*!
	 * \brief Method called for executing a command
	 *
	 * \param[in] command the command to apply on the controller
	 */
	void execute(const string& aCommand);

	virtual void refreshNbFluxgateProperty(int32 value) throw (CannotSetValue);

	void readFieldValues();

	Property<int32> nbfluxgate;
	DynamicProperty<int32> ichannel;
	DynamicProperty<float64> Bx;
	DynamicProperty<float64> By;
	DynamicProperty<float64> Bz;

	Property<bool> isconnected;
	Property<bool> isconfigured;

};

}
#endif //STEREOFLUXGATEDRIVER_H
